% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rp.wire.R
\name{rp.wire}
\alias{rp.wire}
\title{A panel to rotate and choose the better view angle of a
    wireframe}
\usage{
rp.wire(wire)
}
\arguments{
\item{wire}{a wireframe object.}
}
\value{
Open a window with sliders for \code{x}, \code{y} and
    \code{z}. Print the \code{dput} of the last view angle using the
    button.
}
\description{
A panel (gui) rotate a wireframe plot and choose the
    best view angle.

\if{html}{\figure{rp-wire.png}{options: width="700px"}}
\if{latex}{\figure{rp-wire.pdf}{options: width=5.4in}}
}
\examples{

\donttest{
# A simple example.

library(rpanel)
library(lattice)
library(latticeExtra)
library(RColorBrewer)

colr <- brewer.pal(11, "Spectral")
colr <- colorRampPalette(colr, space = "rgb")

grid <- expand.grid(x = seq(-1, 1, by = 0.1),
                    y = seq(-1, 1, by = 0.1))
grid$z <- with(grid, 1 + 0.01 * x + 0.05 * y -
                     0.5 * x * y - 0.5 * x^2 - 0.2 * y^2)

p1 <- wireframe(z ~ x + y, data = grid,
                scales = list(arrows = FALSE),
                col.regions = colr(101), drape = TRUE)
p1

# Choose the better angle.
rp.wire(p1)

}

}
\author{
Walmes Zeviani, \email{walmes@ufpr.br}.
}
\seealso{
\code{\link[lattice]{wireframe}},
    \code{\link[wzRfun]{panel.3d.contour}}.
}
\keyword{GUI}

